==> 0.0.1.tar.gz: lib/mimetype.dart <==
List<String> imageMimeType = [
  "image/gif",
  "image/jpg",
  "image/jpeg",
  "image/png",
  "image/x-png",
  "image/tiff",
  "image/bmp",
  "image/svg+xml",
  "image/webp",
  "image/vnd.microsoft.icon",
  "image/webp",
];

List<String> videoMimeType = [
  "application/x-flash-video",
  "application/x-shockwave-flash",
  "video/mp4",
  "video/webm",
  "video/x-ms-asf",
  "video/x-msvideo",
  "video/x-matroska",
  "video/quicktime",
  "video/mpeg",
  "video/x-ms-wmv",
  "video/x-msvideo",
  "video/ogg",
  "video/mp2t",
  "video/3gpp2"
];

List<String> audioMimeType = [
  "audio/mp3",
  "audio/mpeg",
  "audio/mpeg3",
  "audio/x-mpeg-3",
  "audio/ogg",
  "audio/x-vorbis+ogg",
  "audio/mp4",
  "audio/wav",
  "audio/x-wav",
  "audio/x-ms-wma",
  "audio/aac",
  "audio/opus",
  "audio/webm",
  "audio/3gpp2"
];

List<String> docMimeType = [
  "application/vnd.openxmlformats-officedocument.wordprocessingml.document",
  "application/msword",
  "application/vnd.ms-word",
  "application/doc",
  "application/text",
  "application/vnd.msword",
  "application/winword",
  "application/word",
  "application/x-msw6",
  "application/x-msword",
  "application/x-abiword",
  "application/x-freearc"
];

List<String> excelMimeType = [
  "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
  "application/vnd.ms-excel",
  "application/msexcel",
  "application/x-msexcel",
  "application/x-ms-excel",
  "application/x-excel",
  "application/x-dos_ms_excel",
  "application/xls",
];

List<String> powerpointMimeType = [
  "application/vnd.openxmlformats-officedocument.presentationml.presentation",
  "application/vnd.ms-powerpoint",
  "application/mspowerpoint",
  "application/ms-powerpoint",
  "application/mspowerpnt",
  "application/vnd-mspowerpoint",
  "application/powerpoint",
  "application/x-powerpoint",
  "application/x-m",
];

List<String> googleDriveMimeType = [
  "application/vnd.google-apps.document",
  "application/vnd.google-apps.spreadsheet",
  "application/vnd.google-apps.presentation",
];

List<String> pdfMimeType = [
  "application/pdf",
  "application/x-pdf",
  "application/acrobat",
  "application/vnd.pdf",
  "text/pdf",
  "text/x-pdf",
];

List<String> libreOfficeWriterMimeType = [
  "application/vnd.sun.xml.writer",
  "application/vnd.oasis.opendocument.text",
  "application/application/x-vnd.oasis.opendocument.text",
];

List<String> libreOfficeImpressMimeType = [
  "application/vnd.sun.xml.impress",
  "application/vnd.oasis.opendocument.presentation",
  "application/x-vnd.oasis.opendocument.presentation",
];

List<String> libreOfficeCalcMimeType = [
  "application/vnd.sun.xml.calc",
  "application/vnd.oasis.opendocument.spreadsheet",
  "application/x-vnd.oasis.opendocument.spreadsheet",
];

List<String> ebookMimeType = ["application/vnd.amazon.ebook", "application/epub+zip"];

List<String> compressedFileMimeType = [
  "application/gzip",
  "application/zip",
  "application/x-bzip",
  "application/x-bzip2",
  "application/x-zip-compressed",
  "application/x-tar",
  "application/x-tar-gz",
  "application/vnd.rar",
  "application/x-7z-compressed",
];

List<String> codeMimeType = [
  "text/html",
  "text/css",
  "text/javascript",
  "application/java-archive",
  "application/x-httpd-php",
  "application/x-sh",
  "application/xml",
  "application/xhtml+xml",
];

List<String> calendarMimeType = ["text/calendar"];

List<String> jsonMimeType = [
  "application/json",
  "application/ld+json",
];

List<String> fontMimeType = [
  "font/otf",
  "font/ttf",
  "font/woff",
  "font/woff2",
];

List<String> genericMimeType = [
  "text/plain",
  "application/octet-stream",
  "text/csv",
  "text/vtt",
  "application/msword",
  "application/mswrite",
  "application/vnd.ms-fontobject",
  "application/ogg",
  "application/vnd.apple.installer+xml",
  "application/rtf",
  "application/x-shockwave-flash",
  "application/vnd.visio",
];

==> 0.0.2.tar.gz: lib/mimetype.dart <==
List<String> imageMimeType = [
  "image/gif",
  "image/jpg",
  "image/jpeg",
  "image/png",
  "image/x-png",
  "image/tiff",
  "image/bmp",
  "image/svg+xml",
  "image/webp",
  "image/vnd.microsoft.icon",
  "image/webp",
];

List<String> videoMimeType = [
  "application/x-flash-video",
  "application/x-shockwave-flash",
  "video/mp4",
  "video/webm",
  "video/x-ms-asf",
  "video/x-msvideo",
  "video/x-matroska",
  "video/quicktime",
  "video/mpeg",
  "video/x-ms-wmv",
  "video/x-msvideo",
  "video/ogg",
  "video/mp2t",
  "video/3gpp2"
];

List<String> audioMimeType = [
  "audio/mp3",
  "audio/mpeg",
  "audio/mpeg3",
  "audio/x-mpeg-3",
  "audio/ogg",
  "audio/x-vorbis+ogg",
  "audio/mp4",
  "audio/wav",
  "audio/x-wav",
  "audio/x-ms-wma",
  "audio/aac",
  "audio/opus",
  "audio/webm",
  "audio/3gpp2"
];

List<String> docMimeType = [
  "application/vnd.openxmlformats-officedocument.wordprocessingml.document",
  "application/msword",
  "application/vnd.ms-word",
  "application/doc",
  "application/text",
  "application/vnd.msword",
  "application/winword",
  "application/word",
  "application/x-msw6",
  "application/x-msword",
  "application/x-abiword",
  "application/x-freearc"
];

List<String> excelMimeType = [
  "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
  "application/vnd.ms-excel",
  "application/msexcel",
  "application/x-msexcel",
  "application/x-ms-excel",
  "application/x-excel",
  "application/x-dos_ms_excel",
  "application/xls",
];

List<String> powerpointMimeType = [
  "application/vnd.openxmlformats-officedocument.presentationml.presentation",
  "application/vnd.ms-powerpoint",
  "application/mspowerpoint",
  "application/ms-powerpoint",
  "application/mspowerpnt",
  "application/vnd-mspowerpoint",
  "application/powerpoint",
  "application/x-powerpoint",
  "application/x-m",
];

List<String> googleDriveMimeType = [
  "application/vnd.google-apps.document",
  "application/vnd.google-apps.spreadsheet",
  "application/vnd.google-apps.presentation",
];

List<String> pdfMimeType = [
  "application/pdf",
  "application/x-pdf",
  "application/acrobat",
  "application/vnd.pdf",
  "text/pdf",
  "text/x-pdf",
];

List<String> libreOfficeWriterMimeType = [
  "application/vnd.sun.xml.writer",
  "application/vnd.oasis.opendocument.text",
  "application/application/x-vnd.oasis.opendocument.text",
];

List<String> libreOfficeImpressMimeType = [
  "application/vnd.sun.xml.impress",
  "application/vnd.oasis.opendocument.presentation",
  "application/x-vnd.oasis.opendocument.presentation",
];

List<String> libreOfficeCalcMimeType = [
  "application/vnd.sun.xml.calc",
  "application/vnd.oasis.opendocument.spreadsheet",
  "application/x-vnd.oasis.opendocument.spreadsheet",
];

List<String> ebookMimeType = [
  "application/vnd.amazon.ebook",
  "application/epub+zip"
];

List<String> compressedFileMimeType = [
  "application/gzip",
  "application/zip",
  "application/x-bzip",
  "application/x-bzip2",
  "application/x-zip-compressed",
  "application/x-tar",
  "application/x-tar-gz",
  "application/vnd.rar",
  "application/x-7z-compressed",
];

List<String> codeMimeType = [
  "text/html",
  "text/css",
  "text/javascript",
  "application/java-archive",
  "application/x-httpd-php",
  "application/x-sh",
  "application/xml",
  "application/xhtml+xml",
];

List<String> calendarMimeType = ["text/calendar"];

List<String> jsonMimeType = [
  "application/json",
  "application/ld+json",
];

List<String> fontMimeType = [
  "font/otf",
  "font/ttf",
  "font/woff",
  "font/woff2",
];

List<String> genericMimeType = [
  "text/plain",
  "application/octet-stream",
  "text/csv",
  "text/vtt",
  "application/msword",
  "application/mswrite",
  "application/vnd.ms-fontobject",
  "application/ogg",
  "application/vnd.apple.installer+xml",
  "application/rtf",
  "application/x-shockwave-flash",
  "application/vnd.visio",
];
